===========
relaton-bib
===========


.. image:: https://img.shields.io/pypi/v/relaton_bib.svg
        :target: https://pypi.python.org/pypi/relaton_bib

.. image:: https://github.com/relaton/relaton-bib-py/actions/workflows/test.yml/badge.svg
        :target: https://github.com/relaton/relaton-bib-py/actions/workflows/test.yml

.. image:: https://readthedocs.org/projects/relaton-bib/badge/?version=latest
        :target: https://relaton-bib.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/relaton/relaton_bib/shield.svg
     :target: https://pyup.io/repos/github/relaton/relaton_bib/
     :alt: Updates



Python implementation of https://github.com/relaton/relaton-models#bibliography-uml-models


* Free software: BSD license


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

